@@ -3,7 +3,7 @@
 ## =============================
 
 plot.stslist <- function(x, tlim=NULL, weighted=TRUE, sortv=NULL, 
-	cpal=NULL, missing.color=NULL, ylab=NULL, yaxis=TRUE, xaxis=TRUE, xtlab=NULL, cex.plot=1, ...) {
+	cpal=NULL, missing.color=NULL, ylab=NULL, yaxis=TRUE, xaxis=TRUE, ytlab=NULL, ylas=0, xtlab=NULL, cex.plot=1, ...) {
 
 	n <- nrow(x)
 	seql <- ncol(x)
@@ -68,7 +68,7 @@ plot.stslist <- function(x, tlim=NULL, weighted=TRUE, sortv=NULL,
 	else {wlab <- NULL}
 
 	if (is.null(ylab))
-		ylab <- paste(length(tlim)," seq. ", "(", wlab,"n=",sum(weights),")", 
+		ylab <- paste(length(tlim)," seq. ", "(", wlab,"n=", round(sum(weights),2),")", 
 			sortlab, sep="")
 
 	## The PLot
@@ -104,7 +104,7 @@ plot.stslist <- function(x, tlim=NULL, weighted=TRUE, sortv=NULL,
 			}
 		}
 		else {
-			y.lab.pos <- (weights[1]/2)+1
+			y.lab.pos <- (weights[1]/2)+sp
 			sep <- sp*mean(weights)
 
 			if (idxmax>1) {
@@ -113,7 +113,10 @@ plot.stslist <- function(x, tlim=NULL, weighted=TRUE, sortv=NULL,
 			}
 		}
 
-		axis(2, at=y.lab.pos, mgp=c(1.5,0.5,0), labels=tlim, tick=FALSE, cex.axis=cex.plot)
+		if (is.null(ytlab)) {ytlab <- tlim}
+		else if (ytlab=="id") {ytlab <- rownames(x)[tlim]}
+
+		axis(2, at=y.lab.pos, mgp=c(1.5,0.5,0), labels=ytlab, las=ylas, tick=FALSE, cex.axis=cex.plot)
 	}
 
 }
